==> aster-full-src-7.4.0-4.tar.gz: STA7.4/bibfor/algorith/ndiner.f <==
      SUBROUTINE NDINER(MASSE,VITPLU,FOINER,CMD,INST,A0VIT)

C            CONFIGURATION MANAGEMENT OF EDF VERSION
C MODIF ALGORITH  DATE 03/07/2001   AUTEUR PABHHHH N.TARDIEU 
C ======================================================================
C COPYRIGHT (C) 1991 - 2001  EDF R&D                  WWW.CODE-ASTER.ORG
C THIS PROGRAM IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY
C IT UNDER THE TERMS OF THE GNU GENERAL PUBLIC LICENSE AS PUBLISHED BY
C THE FREE SOFTWARE FOUNDATION; EITHER VERSION 2 OF THE LICENSE, OR   
C (AT YOUR OPTION) ANY LATER VERSION.                                 
C
C THIS PROGRAM IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT 
C WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF          
C MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU    
C GENERAL PUBLIC LICENSE FOR MORE DETAILS.                            
C
C YOU SHOULD HAVE RECEIVED A COPY OF THE GNU GENERAL PUBLIC LICENSE   
C ALONG WITH THIS PROGRAM; IF NOT, WRITE TO EDF R&D CODE_ASTER,       
C    1 AVENUE DU GENERAL DE GAULLE, 92141 CLAMART CEDEX, FRANCE.      
C ======================================================================
C RESPONSABLE PABHHHH N.TARDIEU

      IMPLICIT      NONE
      REAL*8        INST(3),A0VIT
      CHARACTER*16 CMD
      CHARACTER*19 FOINER
      CHARACTER*24 MASSE,VITPLU
C
C ----------------------------------------------------------------------
C
C           DYNA_NON_LINE : CALCUL DE LA FORCE D'INERTIE
C
C ----------------------------------------------------------------------
C
C      IN  MASSE  K24  MATRICE DE MASSE ASSEMBLEE
C      IN  VITPLU K24  MODELE MECANIQUE
C      IN  CMD    K16  ON EST EN STATIQUE OU DYNAMIQUE
C      IN  INST   R*8  PARAMETRES INTEGRATION EN TEMPS (T+, DT, THETA)
C      IN  AOVIT  R*8  COEF METHODES NEWMARK OU HHT
C      OUT FOINER K19  VECTEUR DES FORCES D'INERTIE
C
C --- DEBUT DECLARATIONS NORMALISEES JEVEUX ----------------------------
C
      CHARACTER*32       JEXNUM , JEXNOM , JEXR8 , JEXATR
      INTEGER            ZI
      COMMON  / IVARJE / ZI(1)
      REAL*8             ZR
      COMMON  / RVARJE / ZR(1)
      COMPLEX*16         ZC
      COMMON  / CVARJE / ZC(1)
      LOGICAL            ZL
      COMMON  / LVARJE / ZL(1)
      CHARACTER*8        ZK8
      CHARACTER*16                ZK16
      CHARACTER*24                          ZK24
      CHARACTER*32                                    ZK32
      CHARACTER*80                                              ZK80
      COMMON  / KVARJE / ZK8(1) , ZK16(1) , ZK24(1) , ZK32(1) , ZK80(1)
C
C --- FIN DECLARATIONS NORMALISEES JEVEUX ------------------------------

      INTEGER      POINTM,JFOINE,JVITP,NEQ
      REAL*8       A0VIT1
      CHARACTER*8 K8BID
C ----------------------------------------------------------------------

      CALL JEMARQ()

      IF (CMD(1:4).EQ.'DYNA') THEN
        CALL JEVEUO(MASSE (1:19)//'.&INT','L',POINTM)           
        CALL JEVEUO(FOINER(1:19)//'.VALE','E',JFOINE)
        CALL JEVEUO(VITPLU(1:19)//'.VALE','L',JVITP)
        CALL JELIRA(VITPLU(1:19)//'.VALE','LONMAX',NEQ,K8BID)
        CALL MRMULT('ZERO',POINTM,ZR(JVITP),'R',ZR(JFOINE),1)
        A0VIT1 = A0VIT/INST(2)
        CALL R8SCAL(NEQ,-A0VIT1,ZR(JFOINE),1)
      ENDIF

      CALL JEDEMA()
      END

==> aster-full-src-8.1.0-1.tar.gz: STA8.1/bibfor/algorith/ndiner.f <==
      SUBROUTINE NDINER(MASSE,VITPLU,FOINER,CMD,INST,A0VIT)

C            CONFIGURATION MANAGEMENT OF EDF VERSION
C MODIF ALGORITH  DATE 16/12/2004   AUTEUR VABHHTS J.PELLET 
C ======================================================================
C COPYRIGHT (C) 1991 - 2001  EDF R&D                  WWW.CODE-ASTER.ORG
C THIS PROGRAM IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY
C IT UNDER THE TERMS OF THE GNU GENERAL PUBLIC LICENSE AS PUBLISHED BY
C THE FREE SOFTWARE FOUNDATION; EITHER VERSION 2 OF THE LICENSE, OR   
C (AT YOUR OPTION) ANY LATER VERSION.                                 
C
C THIS PROGRAM IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT 
C WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF          
C MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU    
C GENERAL PUBLIC LICENSE FOR MORE DETAILS.                            
C
C YOU SHOULD HAVE RECEIVED A COPY OF THE GNU GENERAL PUBLIC LICENSE   
C ALONG WITH THIS PROGRAM; IF NOT, WRITE TO EDF R&D CODE_ASTER,       
C    1 AVENUE DU GENERAL DE GAULLE, 92141 CLAMART CEDEX, FRANCE.      
C ======================================================================
C RESPONSABLE PABHHHH N.TARDIEU

      IMPLICIT      NONE
      REAL*8        INST(3),A0VIT
      CHARACTER*16 CMD
      CHARACTER*19 FOINER
      CHARACTER*24 MASSE,VITPLU
C
C ----------------------------------------------------------------------
C
C           DYNA_NON_LINE : CALCUL DE LA FORCE D'INERTIE
C
C ----------------------------------------------------------------------
C
C      IN  MASSE  K24  MATRICE DE MASSE ASSEMBLEE
C      IN  VITPLU K24  MODELE MECANIQUE
C      IN  CMD    K16  ON EST EN STATIQUE OU DYNAMIQUE
C      IN  INST   R*8  PARAMETRES INTEGRATION EN TEMPS (T+, DT, THETA)
C      IN  AOVIT  R*8  COEF METHODES NEWMARK OU HHT
C      OUT FOINER K19  VECTEUR DES FORCES D'INERTIE
C
C --- DEBUT DECLARATIONS NORMALISEES JEVEUX ----------------------------
C
      CHARACTER*32       JEXNUM , JEXNOM , JEXR8 , JEXATR
      INTEGER            ZI
      COMMON  / IVARJE / ZI(1)
      REAL*8             ZR
      COMMON  / RVARJE / ZR(1)
      COMPLEX*16         ZC
      COMMON  / CVARJE / ZC(1)
      LOGICAL            ZL
      COMMON  / LVARJE / ZL(1)
      CHARACTER*8        ZK8
      CHARACTER*16                ZK16
      CHARACTER*24                          ZK24
      CHARACTER*32                                    ZK32
      CHARACTER*80                                              ZK80
      COMMON  / KVARJE / ZK8(1) , ZK16(1) , ZK24(1) , ZK32(1) , ZK80(1)
C
C --- FIN DECLARATIONS NORMALISEES JEVEUX ------------------------------

      INTEGER      POINTM,JFOINE,JVITP,NEQ
      REAL*8       A0VIT1
      CHARACTER*8 K8BID
C ----------------------------------------------------------------------

      CALL JEMARQ()

      IF (CMD(1:4).EQ.'DYNA') THEN
        CALL JEVEUO(MASSE (1:19)//'.&INT','L',POINTM)           
        CALL JEVEUO(FOINER(1:19)//'.VALE','E',JFOINE)
        CALL JEVEUO(VITPLU(1:19)//'.VALE','L',JVITP)
        CALL JELIRA(VITPLU(1:19)//'.VALE','LONMAX',NEQ,K8BID)
        CALL MRMULT('ZERO',POINTM,ZR(JVITP),'R',ZR(JFOINE),1)
        A0VIT1 = A0VIT/INST(2)
        CALL DSCAL(NEQ,-A0VIT1,ZR(JFOINE),1)
      ENDIF

      CALL JEDEMA()
      END
